==> oss-0.0.2.jar: pl/edu/icm/yadda/service3/archive/db/scripts/sqlite/schema2-init.sql <==

CREATE TABLE /*TABLE_PREFIX*/archive_object (
    _pk BIGINT PRIMARY KEY,
    id VARCHAR NOT NULL,
    version VARCHAR NOT NULL,
    branch VARCHAR NOT NULL,
    display_name VARCHAR,
    object_timestamp TIMESTAMP NOT NULL,
    status VARCHAR NOT NULL,
    object_type VARCHAR NOT NULL,
	history BOOLEAN NOT NULL DEFAULT false,
    alt_id VARCHAR,
    alt_branch VARCHAR,
    alt_version VARCHAR, 
    alt_display_name VARCHAR,           
    parent__pk BIGINT REFERENCES /*TABLE_PREFIX*/archive_object(_pk),
	parent_id VARCHAR,
    parent_version VARCHAR,
	parent_branch VARCHAR,
	parent_display_name VARCHAR,
	parent_relation_name VARCHAR,
	parent_position INTEGER,
    schema_type VARCHAR	
);

CREATE TABLE /*TABLE_PREFIX*/archive_index (
	path VARCHAR(1024) NOT NULL,
	pk BIGINT NOT NULL,
	deleted BOOLEAN NOT NULL,
	PRIMARY KEY (path, pk)
);

CREATE TABLE /*TABLE_PREFIX*/archive_tag (
    owner__pk BIGINT REFERENCES /*TABLE_PREFIX*/archive_object(_pk),
    tag_value VARCHAR,
    PRIMARY KEY(owner__pk, tag_value)
);

CREATE TABLE /*TABLE_PREFIX*/archive_content_part (
    id VARCHAR NOT NULL PRIMARY KEY,
    parent__id BIGINT REFERENCES /*TABLE_PREFIX*/archive_object(_pk),
    size INT4,
	path VARCHAR,
	direct_content BYTEA,
    data_type VARCHAR,
	mime VARCHAR,
	md5 VARCHAR
);

CREATE TABLE /*TABLE_PREFIX*/archive_empty_file (
	path VARCHAR NOT NULL PRIMARY KEY
);

CREATE UNIQUE INDEX /*TABLE_PREFIX*/idx_archive_object_ivb ON /*TABLE_PREFIX*/archive_object(id, version, branch);

CREATE INDEX /*TABLE_PREFIX*/idx_archive_index_path ON /*TABLE_PREFIX*/archive_index (path);

CREATE INDEX /*TABLE_PREFIX*/idx_archive_index_pk ON /*TABLE_PREFIX*/archive_index (pk);

CREATE INDEX /*TABLE_PREFIX*/idx_archive_part__id ON /*TABLE_PREFIX*/archive_content_part (parent__id);

CREATE INDEX /*TABLE_PREFIX*/idx_archive_object_parent ON /*TABLE_PREFIX*/archive_object (parent__pk, parent_relation_name);

==> oss-0.1.5.jar: pl/edu/icm/yadda/service3/archive/db/scripts/sqlite/schema2-init.sql <==

CREATE TABLE /*TABLE_PREFIX*/archive_object (
    _pk BIGINT PRIMARY KEY,
    id VARCHAR NOT NULL,
    version VARCHAR NOT NULL,
    branch VARCHAR NOT NULL,
    display_name VARCHAR,
    object_timestamp TIMESTAMP NOT NULL,
    status VARCHAR NOT NULL,
    object_type VARCHAR NOT NULL,
	history BOOLEAN NOT NULL DEFAULT false,
    alt_id VARCHAR,
    alt_branch VARCHAR,
    alt_version VARCHAR, 
    alt_display_name VARCHAR,           
    parent__pk BIGINT REFERENCES /*TABLE_PREFIX*/archive_object(_pk),
	parent_id VARCHAR,
    parent_version VARCHAR,
	parent_branch VARCHAR,
	parent_display_name VARCHAR,
	parent_relation_name VARCHAR,
	parent_position INTEGER,
    schema_type VARCHAR	
);

CREATE TABLE /*TABLE_PREFIX*/archive_index (
	path VARCHAR(1024) NOT NULL,
	pk BIGINT NOT NULL,
	deleted BOOLEAN NOT NULL,
	PRIMARY KEY (path, pk)
);

CREATE TABLE /*TABLE_PREFIX*/archive_tag (
    owner__pk BIGINT REFERENCES /*TABLE_PREFIX*/archive_object(_pk),
    tag_value VARCHAR,
    PRIMARY KEY(owner__pk, tag_value)
);

CREATE TABLE /*TABLE_PREFIX*/archive_content_part (
    id VARCHAR NOT NULL PRIMARY KEY,
    parent__id BIGINT REFERENCES /*TABLE_PREFIX*/archive_object(_pk),
    size INT4,
	path VARCHAR,
	direct_content BLOB,
    data_type VARCHAR,
	mime VARCHAR,
	md5 VARCHAR
);

CREATE TABLE /*TABLE_PREFIX*/archive_empty_file (
	path VARCHAR NOT NULL PRIMARY KEY
);

CREATE UNIQUE INDEX /*TABLE_PREFIX*/idx_archive_object_ivb ON /*TABLE_PREFIX*/archive_object(id, version, branch);

CREATE INDEX /*TABLE_PREFIX*/idx_archive_index_path ON /*TABLE_PREFIX*/archive_index (path);

CREATE INDEX /*TABLE_PREFIX*/idx_archive_index_pk ON /*TABLE_PREFIX*/archive_index (pk);

CREATE INDEX /*TABLE_PREFIX*/idx_archive_part__id ON /*TABLE_PREFIX*/archive_content_part (parent__id);

CREATE INDEX /*TABLE_PREFIX*/idx_archive_object_parent ON /*TABLE_PREFIX*/archive_object (parent__pk, parent_relation_name);
